anagram
=======

|PyPI| |Wercker| |GitHub license| |PyPI|

I'm a small script that help you get anagram use wordsmith.org.

Install
-------

..

    sudo pip install anagram

Usage
-----

use a single word
~~~~~~~~~~~~~~~~~

..

    $ anagram cat
    1. act
    2. cat

use a sentence
~~~~~~~~~~~~~~

..

    $  anagram a dog
    1. goad
    2. a god
    3. a dog
    4. ad go

Changelog
---------

- v0.0.5

  - first version, with base function.

LICENSE
-------

MIT.


.. |PyPI| image:: https://img.shields.io/pypi/status/Django.svg
   :target: https://github.com/RayYu03/anagramt
.. |Wercker| image:: https://img.shields.io/wercker/ci/wercker/docs.svg
   :target: https://github.com/RayYu03/anagramt
.. |GitHub license| image:: https://img.shields.io/github/license/mashape/apistatus.svg
   :target: https://github.com/RayYu03/anagramt
.. |PyPI| image:: https://img.shields.io/pypi/pyversions/Django.svg
   :target: https://github.com/RayYu03/anagramt
